/*

	Filename:   CDLaunch.prg
   Version:    1.02
   Date:       2000/02/27

   For:        VdBase 7.x / Win9x

   Author:     Ronnie MacGregor
   Contact:    Ronnie@High-Lugtonridge.co.uk

	
   Revisions:
   **********

   2000/02/28  Use of Registry path information added since run()
               will not find an exe without it's path being suppplied,
               even with the appropriate info in the registry.

   2000/02/29  Added check for app already running to deal with the
               app being started on the machine, requesting the CD,
               and the CD then launching a second instance.               


   Description:
   ************

      CDLaunch.exe is designed for applications which need to be
      installed on the users machine, but require to access tables
      which remain on the CD. It allows the CD to Autorun on insertion
      and if the application is found on the machine will run the
      application, otherwise it will initiate the install.  
      

   CDLaunch Syntax:
   ****************

      CDLaunch should be run from an AUTORUN.INF file which contains
      the following:

      [autorun]
      OPEN=CDLaunch.exe  MyAppName.exe
      ICON=MyChosen.ico
  
      N.B. It is important that the .exe is included for the parameter.
   

   Dependancies:
   *************

      Vdb7run.exe Vdb70009.dll (or other language version) and
      Resource.dll must be found in the root directory of the CD

      The application exe must be referenced in a registry key
      in order that we can find it:

      HKEY_LOCAL_MACHINE\\SOFTWARE\Microsoft\Windows\CurrentVersion\
         App Paths\MyApp.exe

      should contain the default keys and values:

      Default  "FullPath\MyApp.exe"
      Path     "FullPath"

      These registry entry can be achieved by using InstallShield
      to make the keys using <INSTALLDIR>\MyApp.exe.

      Registry.prg  winreg.h and windef.h are also required.


   Compilation:
   ************

      CD.ico should be used as the exe icon to be used for the task
      bar button should it hang around long enough to be seen.

      CDLaunch.bmp should be used as the splash screen so that the
      user has something to look at while the program loads up !! 


   Acknowledgements:
   *****************

      Thanks to Gary White in the dBase newsgroups for information
      on the registry.

      Thanks to Dan Howard in the dBase newsgroups for prompting
      me to use the information I had already stuffed in the
      registry to pull the path back out !!!

      Thanks to Romain Streiff for his IsExeOpen.prg in the dUFLP
      whose technique I adapted for use here.
      
             
*/


Function CDLaunch(cExeName)
local cPath, nExeResult, nSetupResult
//
set procedure to registry.prg additive
//
// Check parameter
if empty(argvector(1))
    msgbox("Required parameter not passed.","Call Error",16)
    return
endif
// Try to get app path from registry
try
   set procedure to "Registry.prg" additive
   reg = new Registry((0x80000002),;
      "SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\" + cExeName)
   cPath = reg.queryValue("Path")
catch(Exception e)
   // Just continue !!   
endtry
// Check app not already running
try
   fClose(fOpen(cPath + "\" + cExeName,"RW"))
catch(Exception e )
   if e.code == 108 // file in use by another
      return
      //quit // this causes screen flash 
   endif
endtry
// Try to run app
if(reg.error == 0) // No error
   cd (cPath)
   nExeResult = run(true,cPath + "\" + cExeName)
else
   nExeResult = run(true,cExeName)
endif
// If app didn't run initiate install
if nExeResult # 0 // 0 success, 2 fail
   nSetupResult = run(true,"DISK1\Setup.exe")
   if nSetupResult # 0 // 0 success, 2 fail
      msgbox("Automatic CD launch failed.","CD Error",16)
   endif
endif
// 
return

//eop
